@@ -15,7 +15,6 @@ my $say = sub {
           . "[PNI::Error] from package $package "
           . "in file $filename at line $line\n";
     }
-    return 1;
 };
 
 sub attribute_does_not_exists {
@@ -23,11 +22,6 @@ sub attribute_does_not_exists {
     return;
 }
 
-sub check_data_failed {
-    $say->('check data failed');
-    return;
-}
-
 sub generic {
     $say->('generic');
     return;
@@ -90,8 +84,6 @@ PNI::Error - PNI errors catalogue
 
 =head2 C<attribute_does_not_exists>
 
-=head2 C<check_data_failed>
-
 =head2 C<generic>
 
 =head2 C<invalid_argument_type>
